@@ -785,6 +785,9 @@ class LocalContainerExecutor(BaseExecutor):
         """
         executor_config = self._resolve_executor_config(node)
 
+        logger.debug("Here is the resolved executor config")
+        logger.debug(executor_config)
+
         if "run_in_local" in executor_config and executor_config["run_in_local"]:
             # Do not change config but only validate the configuration.
             integration.validate(self, self.run_log_store)
