@@ -1,14 +1,11 @@
 import json
 import logging
-from typing import Optional, Union
+from typing import Union
 
-from magnus import defaults, exceptions, graph, utils
+from magnus import context, defaults, exceptions, graph, utils
 
 logger = logging.getLogger(defaults.NAME)
 
-# Set this global executor to the fitted executor for access later
-global_executor = None  # pylint: disable=invalid-name # type: ignore
-
 
 def get_default_configs() -> dict:
     """
@@ -34,7 +31,8 @@ def prepare_configurations(
         run_id: str = None,
         tag: Union[str, None] = None,
         use_cached: Union[str, None] = '',
-        parameters_file: str = None):
+        parameters_file: str = None,
+        force_local_executor: bool = False):
     # pylint: disable=R0914
     """
     Replace the placeholders in the dag/config against the variables file.
@@ -81,16 +79,19 @@ def prepare_configurations(
     secrets_handler = utils.get_provider_by_name_and_type('secrets', secrets_config)
 
     # experiment tracker settings, configuration over-rides everything
-    tracker_config = configuration.get('experiment_tracking', {})
+    tracker_config = configuration.get('experiment_tracker', {})
     if not tracker_config:
-        tracker_config = magnus_defaults.get('experiment_tracking', defaults.DEFAULT_EXPERIMENT_TRACKER)
-    tracker_handler = utils.get_provider_by_name_and_type('experiment_tracking', tracker_config)
+        tracker_config = magnus_defaults.get('experiment_tracker', defaults.DEFAULT_EXPERIMENT_TRACKER)
+    tracker_handler = utils.get_provider_by_name_and_type('experiment_tracker', tracker_config)
 
-    # Mode configurations, configuration over rides everything
-    mode_config = configuration.get('mode', {})
-    if not mode_config:
-        mode_config = magnus_defaults.get('executor', defaults.DEFAULT_EXECUTOR)
-    mode_executor = utils.get_provider_by_name_and_type('executor', mode_config)
+    # executor configurations, configuration over rides everything
+    executor_config = configuration.get('executor', {})
+    if force_local_executor:
+        executor_config = {'type': 'local'}
+
+    if not executor_config:
+        executor_config = magnus_defaults.get('executor', defaults.DEFAULT_EXECUTOR)
+    configured_executor = utils.get_provider_by_name_and_type('executor', executor_config)
 
     if pipeline_file:
         # There are use cases where we are only preparing the executor
@@ -106,27 +107,26 @@ def prepare_configurations(
         # TODO: Dag nodes should not self refer themselves
         dag = graph.create_graph(dag_config)
 
-        mode_executor.pipeline_file = pipeline_file
-        mode_executor.dag = dag
-        mode_executor.dag_hash = dag_hash
+        configured_executor.pipeline_file = pipeline_file
+        configured_executor.dag = dag
+        configured_executor.dag_hash = dag_hash
 
-    mode_executor.run_id = run_id
-    mode_executor.tag = tag
-    mode_executor.use_cached = use_cached
+    configured_executor.run_id = run_id
+    configured_executor.tag = tag
+    configured_executor.use_cached = use_cached
 
     # Set a global executor for inter-module access later
-    global global_executor  # pylint: disable=W0603,invalid-name,
-    global_executor = mode_executor
+    context.executor = configured_executor
 
-    mode_executor.run_log_store = run_log_store
-    mode_executor.catalog_handler = catalog_handler
-    mode_executor.secrets_handler = secrets_handler
-    mode_executor.experiment_tracker = tracker_handler
-    mode_executor.configuration_file = configuration_file
-    mode_executor.parameters_file = parameters_file
-    mode_executor.variables = variables
+    configured_executor.run_log_store = run_log_store
+    configured_executor.catalog_handler = catalog_handler
+    configured_executor.secrets_handler = secrets_handler
+    configured_executor.experiment_tracker = tracker_handler
+    configured_executor.configuration_file = configuration_file
+    configured_executor.parameters_file = parameters_file
+    configured_executor.variables = variables
 
-    return mode_executor
+    return configured_executor
 
 
 def execute(
